#ifndef NT2_INCLUDE_FUNCTIONS_MIN_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_MIN_HPP_INCLUDED

#include <nt2/arithmetic/include/functions/min.hpp>

#endif
